/* Copyright.h */

/* This copyright data applies to all source files and all binary files. */

#ifdef _main_c_

char gCopyright1[] = "@(#) \
THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED\n\
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF\n\
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.\n\
\n";

char gCopyright2[] = "\
Copyright (c) 1995 Mike Gleason, NCEMRSoft.\n\
All rights reserved.\n\
\n";

char gCopyright3[] = "\
Redistribution and use in source and binary forms are permitted provided\n\
that: (1) source distributions retain this entire copyright notice and\n\
comment, and (2) distributions may not be sold for profit on physical\n\
media such as disks, tapes, and CD-ROMS, without expressed written\n\
permission.";

#endif

/* eof copyright.h */
